@@ -353,40 +353,6 @@ eel_gtk_menu_tool_button_get_button (GtkMenuToolButton *tool_button)
     return button;
 }
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-/* The standard gtk_adjustment_set_value ignores page size, which
- * disagrees with the logic used by scroll bars, for example.
- */
-void
-eel_gtk_adjustment_set_value (GtkAdjustment *adjustment,
-                              float value)
-{
-    float upper_page_start, clamped_value;
-
-    g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
-
-    upper_page_start = MAX (gtk_adjustment_get_upper (adjustment) -
-                            gtk_adjustment_get_page_size (adjustment),
-                            gtk_adjustment_get_lower (adjustment));
-    clamped_value = CLAMP (value, gtk_adjustment_get_lower (adjustment), upper_page_start);
-    if (clamped_value != gtk_adjustment_get_value (adjustment))
-    {
-        gtk_adjustment_set_value (adjustment, clamped_value);
-        gtk_adjustment_value_changed (adjustment);
-    }
-}
-
-/* Clamp a value if the minimum or maximum has changed. */
-void
-eel_gtk_adjustment_clamp_value (GtkAdjustment *adjustment)
-{
-    g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
-
-    eel_gtk_adjustment_set_value (adjustment,
-                                  gtk_adjustment_get_value (adjustment));
-}
-#endif
-
 /**
  * eel_gtk_label_make_bold.
  *
@@ -408,11 +374,7 @@ eel_gtk_label_make_bold (GtkLabel *label)
      * theme or user prefs, since the font desc only has the
      * weight flag turned on.
      */
-#if GTK_CHECK_VERSION(3,0,0)
     gtk_widget_override_font (GTK_WIDGET (label), font_desc);
-#else
-     gtk_widget_modify_font (GTK_WIDGET (label), font_desc);
-#endif
 
     pango_font_description_free (font_desc);
 }
