@@ -426,11 +426,7 @@ caja_icon_info_lookup (GIcon *icon,
 
         filename = gtk_icon_info_get_filename (gtkicon_info);
         if (filename == NULL) {
-#if GTK_CHECK_VERSION (3, 0, 0)
             g_object_unref (gtkicon_info);
-#else
-            gtk_icon_info_free (gtkicon_info);
-#endif
             return caja_icon_info_new_for_pixbuf (NULL);
         }
 
@@ -440,11 +436,7 @@ caja_icon_info_lookup (GIcon *icon,
         icon_info = g_hash_table_lookup (themed_icon_cache, &lookup_key);
         if (icon_info)
         {
-#if GTK_CHECK_VERSION (3, 0, 0)
             g_object_unref (gtkicon_info);
-#else
-            gtk_icon_info_free (gtkicon_info);
-#endif
             return g_object_ref (icon_info);
         }
 
@@ -453,11 +445,7 @@ caja_icon_info_lookup (GIcon *icon,
         key = themed_icon_key_new (filename, size);
         g_hash_table_insert (themed_icon_cache, key, icon_info);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
         g_object_unref (gtkicon_info);
-#else
-        gtk_icon_info_free (gtkicon_info);
-#endif
 
         return g_object_ref (icon_info);
     }
@@ -473,11 +461,7 @@ caja_icon_info_lookup (GIcon *icon,
         if (gtk_icon_info != NULL)
         {
             pixbuf = gtk_icon_info_load_icon (gtk_icon_info, NULL);
-#if GTK_CHECK_VERSION (3, 0, 0)
             g_object_unref (gtk_icon_info);
-#else
-            gtk_icon_info_free (gtk_icon_info);
-#endif
         }
         else
         {
