@@ -319,7 +319,7 @@ caja_application_open (GApplication *app,
 {
     CajaApplication *self = CAJA_APPLICATION (app);
     gboolean browser_window = FALSE;
-    const gchar *geometry;
+    const gchar *geometry = NULL;
     const char splitter = '=';
 
     g_debug ("Open called on the GApplication instance; %d files", n_files);
@@ -1373,6 +1373,7 @@ mount_added_callback (GVolumeMonitor *monitor,
         caja_directory_force_reload (directory);
         caja_directory_unref (directory);
     }
+	caja_autorun (mount, autorun_show_window, application);
 }
 
 static CajaWindowSlot *
@@ -2226,8 +2227,12 @@ init_icons_and_styles (void)
 
 /* add our desktop CSS provider,  ensures the desktop background does not get covered */
     provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_path (provider,
-				CAJA_DATADIR G_DIR_SEPARATOR_S "caja-desktop.css", &error);
+
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_css_provider_load_from_path (provider, CAJA_DATADIR G_DIR_SEPARATOR_S "caja-desktop.css", &error);
+#else
+    gtk_css_provider_load_from_path (provider, CAJA_DATADIR G_DIR_SEPARATOR_S "caja-desktop-3.14.css", &error);
+#endif
 
     if (error != NULL) {
         g_warning ("Can't parse Caja' CSS custom description: %s\n", error->message);
@@ -2334,6 +2339,9 @@ caja_application_startup (GApplication *app)
      */
     G_APPLICATION_CLASS (caja_application_parent_class)->startup (app);
 
+    /* Start the File Manager DBus Interface */
+    fdb_manager = caja_freedesktop_dbus_new (self);
+
     /* Initialize preferences. This is needed so that proper
      * defaults are available before any preference peeking
      * happens.
