@@ -155,6 +155,7 @@ get_slider_button (CajaPathBar  *path_bar,
 #else
     gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
 #endif
+    gtk_widget_add_events (button, GDK_SCROLL_MASK);
     gtk_container_add (GTK_CONTAINER (button),
                        gtk_image_new_from_icon_name (arrow_type, GTK_ICON_SIZE_MENU));
     gtk_container_add (GTK_CONTAINER (path_bar), button);
@@ -918,6 +919,9 @@ caja_path_bar_scroll (GtkWidget      *widget,
     case GDK_SCROLL_UP:
         caja_path_bar_scroll_up (path_bar);
         return TRUE;
+
+    case GDK_SCROLL_SMOOTH:
+        break;
     }
 
     return FALSE;
@@ -1336,47 +1340,6 @@ button_clicked_cb (GtkWidget *button,
     g_signal_emit (path_bar, path_bar_signals [PATH_CLICKED], 0, button_data->path);
 }
 
-static CajaIconInfo *
-get_custom_user_icon_info (ButtonData *button_data)
-{
-    /* Bug 80925: With tiny display sizes we get huge memory allocations. */
-#if 0
-    CajaIconInfo *icon_info;
-    GFile *icon_file;
-    GIcon *icon;
-    char *custom_icon_uri;
-
-    icon = NULL;
-
-    if (button_data->file != NULL)
-    {
-        custom_icon_uri = caja_file_get_custom_icon (button_data->file);
-        if (custom_icon_uri != NULL)
-        {
-            icon_file = g_file_new_for_uri (custom_icon_uri);
-
-            if (g_file_is_native (icon_file))
-            {
-                icon = g_file_icon_new (icon_file);
-            }
-
-            g_object_unref (icon_file);
-            g_free (custom_icon_uri);
-        }
-    }
-
-    if (icon != NULL)
-    {
-        icon_info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE);
-        g_object_unref (icon);
-
-        return icon_info;
-    }
-#endif
-
-    return NULL;
-}
-
 static CajaIconInfo *
 get_type_icon_info (ButtonData *button_data)
 {
@@ -1467,7 +1430,9 @@ set_label_padding_size (ButtonData *button_data)
     pango_layout_get_pixel_size (layout, &bold_width, &bold_height);
 
     pad_left = (bold_width - width) / 2;
-    pad_right = (bold_width - width) / 2;
+    pad_right = (bold_width + 1 - width) / 2; /* this ensures rounding up - the
+    pixel size difference between bold and normal fonts is not always even and
+    will give an off-by-one error when dividing by 2 */
 
     gtk_widget_set_margin_start (GTK_WIDGET (button_data->label), pad_left);
     gtk_widget_set_margin_end (GTK_WIDGET (button_data->label), pad_right);
@@ -1511,12 +1476,7 @@ caja_path_bar_update_button_appearance (ButtonData *button_data)
         }
         else
         {
-            icon_info = get_custom_user_icon_info (button_data);
-            if (icon_info == NULL)
-            {
-                icon_info = get_type_icon_info (button_data);
-            }
-
+            icon_info = get_type_icon_info (button_data);
             pixbuf = NULL;
 
             if (icon_info != NULL)
@@ -1886,6 +1846,7 @@ make_directory_button (CajaPathBar  *path_bar,
 #else
     gtk_button_set_focus_on_click (GTK_BUTTON (button_data->button), FALSE);
 #endif
+    gtk_widget_add_events (button_data->button, GDK_SCROLL_MASK);
     /* TODO update button type when xdg directories change */
 
     button_data->drag_info.target_location = g_object_ref (path);
@@ -2150,60 +2111,6 @@ caja_path_bar_get_path_for_button (CajaPathBar *path_bar,
     return NULL;
 }
 
-/**
- * _caja_path_bar_up:
- * @path_bar: a #CajaPathBar
- *
- * If the selected button in the pathbar is not the furthest button "up" (in the
- * root direction), act as if the user clicked on the next button up.
- **/
-void
-caja_path_bar_up (CajaPathBar *path_bar)
-{
-    GList *l;
-
-    for (l = path_bar->button_list; l; l = l->next)
-    {
-        GtkWidget *button = BUTTON_DATA (l->data)->button;
-        if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
-        {
-            if (l->next)
-            {
-                GtkWidget *next_button = BUTTON_DATA (l->next->data)->button;
-                button_clicked_cb (next_button, l->next->data);
-            }
-            break;
-        }
-    }
-}
-
-/**
- * _caja_path_bar_down:
- * @path_bar: a #CajaPathBar
- *
- * If the selected button in the pathbar is not the furthest button "down" (in the
- * leaf direction), act as if the user clicked on the next button down.
- **/
-void
-caja_path_bar_down (CajaPathBar *path_bar)
-{
-    GList *l;
-
-    for (l = path_bar->button_list; l; l = l->next)
-    {
-        GtkWidget *button = BUTTON_DATA (l->data)->button;
-        if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
-        {
-            if (l->prev)
-            {
-                GtkWidget *prev_button = BUTTON_DATA (l->prev->data)->button;
-                button_clicked_cb (prev_button, l->prev->data);
-            }
-            break;
-        }
-    }
-}
-
 GtkWidget *
 caja_path_bar_get_button_from_button_list_entry (gpointer entry)
 {
