@@ -49,21 +49,13 @@ typedef struct CajaSidebarTitleDetails CajaSidebarTitleDetails;
 
 typedef struct
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
     GtkBox box;
-#else
-    GtkVBox box;
-#endif
     CajaSidebarTitleDetails *details;
 } CajaSidebarTitle;
 
 typedef struct
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
     GtkBoxClass parent_class;
-#else
-    GtkVBoxClass parent_class;
-#endif
 } CajaSidebarTitleClass;
 
 GType      caja_sidebar_title_get_type          (void);
