@@ -42,10 +42,6 @@ static GObjectClass *parent_class = NULL;
 
 #define CAJA_VIEW_AS_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), CAJA_TYPE_VIEW_AS_ACTION, CajaViewAsActionPrivate))
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#endif
-
 struct CajaViewAsActionPrivate
 {
     CajaNavigationWindow *window;
@@ -177,14 +173,14 @@ connect_proxy (GtkAction *action,
         /* Option menu for content view types; it's empty here, filled in when a uri is set.
          * Pack it into vbox so it doesn't grow vertically when location bar does.
          */
-        view_as_menu_vbox = gtk_vbox_new (FALSE, 4);
+        view_as_menu_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 4);
         gtk_widget_show (view_as_menu_vbox);
 
         gtk_container_add (GTK_CONTAINER (item), view_as_menu_vbox);
 
         view_as_combo_box = gtk_combo_box_text_new ();
 
-#if GTK_CHECK_VERSION(3,20,0)
+#if GTK_CHECK_VERSION (3, 20, 0)
         gtk_widget_set_focus_on_click (view_as_combo_box, FALSE);
 #else
         gtk_combo_box_set_focus_on_click (GTK_COMBO_BOX (view_as_combo_box), FALSE);
